@@ -22,8 +22,9 @@ from sqlalchemy.orm import sessionmaker
 from sqlalchemy.pool import SingletonThreadPool
 
 # These need to be declared before we start importing from other flexget modules, since they might import them
+from flexget.utils.sqlalchemy_utils import ContextSession
 Base = declarative_base()
-Session = sessionmaker()
+Session = sessionmaker(class_=ContextSession)
 
 from flexget import config_schema, db_schema, logger
 from flexget.event import fire_event
@@ -277,7 +278,11 @@ class Manager(object):
             except ValueError as e:
                 log.error(e)
             else:
-                client.execute(dict(options, loglevel=self.options.loglevel))
+                try:
+                    client.execute(dict(options, loglevel=self.options.loglevel))
+                except KeyboardInterrupt:
+                    log.error('Disconnecting from daemon due to ctrl-c. Executions will still continue in the '
+                              'background.')
             self.shutdown()
             return
         # Otherwise we run the execution ourselves
