@@ -145,10 +145,10 @@ class TVDBSeries(TVDBContainer, Base):
 
     episodes = relation('TVDBEpisode', backref='series', cascade='all, delete, delete-orphan')
 
-    def update(self):
-        if not self.id:
-            raise LookupError('Cannot update a series without a tvdb id.')
-        url = get_mirror() + api_key + '/series/%s/%s.xml' % (self.id, language)
+    def update(self, tvdb_id=None):
+        if tvdb_id:
+            self.id = tvdb_id
+        url = get_mirror() + api_key + '/series/%s/%s.xml' % (tvdb_id, language)
         try:
             data = requests.get(url).content
         except RequestException as e:
@@ -280,9 +280,24 @@ def find_series_id(name):
         raise LookupError('No results for `%s`' % name)
 
 
-@with_session
+@with_session(expire_on_commit=False)
 def lookup_series(name=None, tvdb_id=None, only_cached=False, session=None):
-    if not name and not tvdb_id:
+    """
+    Look up information on a series. Will be returned from cache if available, and looked up online and cached if not.
+
+    Either `name` or `tvdb_id` parameter are needed to specify the series.
+    :param unicode name: Name of series.
+    :param int tvdb_id: TVDb ID of series.
+    :param bool only_cached: If True, will not cause an online lookup. LookupError will be raised if not available
+        in the cache.
+    :param session: An sqlalchemy session to be used to lookup and store to cache. Commit(s) may occur when passing in
+        a session. If one is not supplied it will be created.
+
+    :return: Instance of :class:`TVDBSeries` populated with series information. If session was not supplied, this will
+        be a detached from the database, so relationships cannot be loaded.
+    :raises: :class:`LookupError` if series cannot be looked up.
+    """
+    if not (name or tvdb_id):
         raise LookupError('No criteria specified for tvdb lookup')
 
     log.debug('Looking up tvdb information for %r' % {'name': name, 'tvdb_id': tvdb_id})
@@ -305,7 +320,7 @@ def lookup_series(name=None, tvdb_id=None, only_cached=False, session=None):
         # Series found in cache, update if cache has expired.
         if not only_cached:
             mark_expired(session=session)
-        if series.expired and not only_cached:
+        if not only_cached and series.expired:
             log.verbose('Data for %s has expired, refreshing from tvdb' % series.seriesname)
             try:
                 series.update()
@@ -320,8 +335,7 @@ def lookup_series(name=None, tvdb_id=None, only_cached=False, session=None):
         log.debug('Series %s not found in cache, looking up from tvdb.' % id_str())
         if tvdb_id:
             series = TVDBSeries()
-            series.id = tvdb_id
-            series.update()
+            series.update(tvdb_id)
             if series.seriesname:
                 session.add(series)
         elif name:
@@ -330,8 +344,7 @@ def lookup_series(name=None, tvdb_id=None, only_cached=False, session=None):
                 series = session.query(TVDBSeries).filter(TVDBSeries.id == tvdb_id).first()
                 if not series:
                     series = TVDBSeries()
-                    series.id = tvdb_id
-                    series.update()
+                    series.update(tvdb_id)
                     session.add(series)
                 if name.lower() != series.seriesname.lower():
                     session.add(TVDBSearchResult(search=name, series=series))
@@ -340,37 +353,57 @@ def lookup_series(name=None, tvdb_id=None, only_cached=False, session=None):
         raise LookupError('No results found from tvdb for %s' % id_str())
     if not series.seriesname:
         raise LookupError('Tvdb result for series does not have a title.')
-    series.episodes
+    session.commit()
     return series
 
 
-@with_session
+@with_session(expire_on_commit=False)
 def lookup_episode(name=None, seasonnum=None, episodenum=None, absolutenum=None, airdate=None,
                    tvdb_id=None, only_cached=False, session=None):
+    """
+    Look up information on an episode. Will be returned from cache if available, and looked up online and cached if not.
+
+    Either `name` or `tvdb_id` parameter are needed to specify the series.
+    Either `seasonnum` and `episodedum`, `absolutenum`, or `airdate` are required to specify episode number.
+    :param unicode name: Name of series episode belongs to.
+    :param int tvdb_id: TVDb ID of series episode belongs to.
+    :param int seasonnum: Season number of episode.
+    :param int episodenum: Episode number of episode.
+    :param int absolutenum: Absolute number of episode.
+    :param int airdate: Air date of episode.
+    :param bool only_cached: If True, will not cause an online lookup. LookupError will be raised if not available
+        in the cache.
+    :param session: An sqlalchemy session to be used to lookup and store to cache. Commit(s) may occur when passing in
+        a session. If one is not supplied it will be created, however if you need to access relationships you should
+        pass one in.
+
+    :return: Instance of :class:`TVDBEpisode` populated with series information.
+    :raises: :class:`LookupError` if episode cannot be looked up.
+    """
     # First make sure we have the series data
     series = lookup_series(name=name, tvdb_id=tvdb_id, only_cached=only_cached, session=session)
-    if not series:
-        raise LookupError('Could not identify series')
     # Set variables depending on what type of identifier we are looking up
-    if airdate:
+    if airdate is not None:
         airdatestring = airdate.strftime('%Y-%m-%d')
         ep_description = '%s.%s' % (series.seriesname, airdatestring)
         episode = session.query(TVDBEpisode).filter(TVDBEpisode.series_id == series.id).\
             filter(TVDBEpisode.firstaired == airdate).first()
         url = get_mirror() + ('GetEpisodeByAirDate.php?apikey=%s&seriesid=%d&airdate=%s&language=%s' %
                              (api_key, series.id, airdatestring, language))
-    elif absolutenum:
+    elif absolutenum is not None:
         ep_description = '%s.%d' % (series.seriesname, absolutenum)
         episode = session.query(TVDBEpisode).filter(TVDBEpisode.series_id == series.id).\
             filter(TVDBEpisode.absolute_number == absolutenum).first()
         url = get_mirror() + api_key + '/series/%d/absolute/%s/%s.xml' % (series.id, absolutenum, language)
-    else:
+    elif seasonnum is not None and episodenum is not None:
         ep_description = '%s.S%sE%s' % (series.seriesname, seasonnum, episodenum)
         # See if we have this episode cached
         episode = session.query(TVDBEpisode).filter(TVDBEpisode.series_id == series.id).\
             filter(TVDBEpisode.seasonnumber == seasonnum).\
             filter(TVDBEpisode.episodenumber == episodenum).first()
         url = get_mirror() + api_key + '/series/%d/default/%d/%d/%s.xml' % (series.id, seasonnum, episodenum, language)
+    else:
+        raise LookupError('No episode identifier specified.')
     if episode:
         if episode.expired and not only_cached:
             log.info('Data for %r has expired, refreshing from tvdb' % episode)
@@ -405,8 +438,7 @@ def lookup_episode(name=None, seasonnum=None, episodenum=None, absolutenum=None,
         except RequestException as e:
             raise LookupError('Error looking up episode from TVDb (%s)' % e)
     if episode:
-        # Access the series attribute to force it to load before returning
-        episode.series
+        session.commit()
         return episode
     else:
         raise LookupError('No results found for ')
@@ -422,7 +454,7 @@ def mark_expired(session=None):
     if not last_local:
         # Never run before? Lets reset ALL series
         log.info('Setting all series to expire')
-        session.query(TVDBSeries).update({'expired': True}, 'fetch')
+        session.query(TVDBSeries).update({'expired': True}, synchronize_session='fetch')
         persist['last_local'] = datetime.now()
         return
     elif last_local + timedelta(hours=6) > datetime.now():
@@ -456,7 +488,7 @@ def mark_expired(session=None):
     if updates is not None:
         new_server = int(updates.attrib['time'])
 
-        if new_server < last_server:
+        if new_server <= last_server:
             #nothing changed on the server, ignoring
             log.debug("Not checking for expired as nothing has changed on server")
             return
@@ -485,5 +517,6 @@ def mark_expired(session=None):
             log.debug('%s episodes marked as expired' % num)
 
         # Save the time of this update
+        session.commit()
         persist['last_local'] = datetime.now()
         persist['last_server'] = new_server
