@@ -81,7 +81,7 @@ class TaskQueue(object):
             while self._thread.is_alive():
                 time.sleep(0.5)
         except KeyboardInterrupt:
-            log.error('Got ctrl-c, shutting down after this task finishes')
+            log.error('Got ctrl-c, shutting down after running task (if any) completes')
             self.shutdown(finish_queue=False)
             # We still wait to finish cleanly, pressing ctrl-c again will abort
             while self._thread.is_alive():
